
# pips

> PIPS = Pips Installs Packages Securely
>
> The last package you'll install with pip.


[![pips workflow](https://github.com/samocorp/pips/actions/workflows/release.yaml/badge.svg?branch=main)](https://github.com/samocorp/pips/actions/workflows/release.yaml/badge)
[![PyPI version](https://badge.fury.io/py/pipsamo.svg)](https://badge.fury.io/py/pipsamo)


## Table of Contents

- [Installation](#installation)
- [Usage](#usage)


## Installation

This will the last package you install with pip.

From this point on, there will be no reason to install packages dangerously and unsecurely.

Most tend to find themselves using pips forever immediately after installation. User Beware.

    $ pip install pipsamo
    
Important to remember: 

 -> the **package** is named `pipsamo`

 -> the **script** is named `pips`


## Usage

TL / DR: ADD AN S TO EVERY COMMAND.

Every `pip` will now become `pips`.

Simple, right?

For example:

    $ pips install pygame
    $ pips uninstall requests
    
    
## Bless the Authors

All rights reserved.

This project was started by SAMO in 2020.

![SAMO c 2020](https://news.artnet.com/app/news-upload/2020/06/IMG_0779-2.jpg)


Thank you for reading.